@@ -114,7 +114,7 @@ class Builder(Update):
 
     def mount_target(self, target):
         dir_distro = target.convertToDirectory()
-        dir_distro.mountSystemDirectories(skip=())
+        dir_distro.mountSystemDirectories(skip=('efivars'))
         return True
 
     def umount_system(self, target):
@@ -2270,4 +2270,4 @@ class Builder(Update):
                 self.clVars.Write("cl_update_saved_tag", str(tag), location="system")
             return True
         except ValueError as e:
-            return False
\ No newline at end of file
+            return False
